@@ -5,6 +5,7 @@ namespace Doctrine\Tests\Common\Annotations\Ticket;
 use Doctrine\Common\Annotations\AnnotationReader;
 use PHPUnit\Framework\TestCase;
 use ReflectionClass;
+use SimpleXMLElement;
 
 /**
  * @group
@@ -44,7 +45,7 @@ class DCOM141Annotation
 }
 
 /**
- * @DCOM141Annotation(\SimpleXMLElement::class)
+ * @DCOM141Annotation(SimpleXMLElement::class)
  */
 class DCOM141ConsumerPrefixed
 {
